@@ -39,6 +39,10 @@ class Standards(_Enum):  # pragma: no cover
     NAF1 = "NAF1"
     NAF2 = "NAF2"
     GCED2011 = "GCED2011"
+    SCIAN2018 = "SCIAN2018"
+    CCNAE2021 = "CCNAE2021"
+    CAEM2005 = "CAEM2005"
+    CAEM2009 = "CAEM2009"
 
 
 @_dataclass
